@@ -56,7 +56,8 @@ public:
   sigc::signal<void, Gnome::Gda::Value> signal_record_added;
 
   bool get_has_suitable_record_to_view_details() const;
-  void get_suitable_record_to_view_details(const Gnome::Gda::Value& primary_key_value, Glib::ustring& table_name, Gnome::Gda::Value& table_primary_key_value);
+  void get_suitable_table_to_view_details(Glib::ustring& table_name, sharedptr<const UsesRelationship>& relationship) const;
+  void get_suitable_record_to_view_details(const Gnome::Gda::Value& primary_key_value, Glib::ustring& table_name, Gnome::Gda::Value& table_primary_key_value) const;
 
   ///@param relationship_name
   typedef sigc::signal<void, const Glib::ustring&> type_signal_record_changed;
@@ -66,9 +67,6 @@ protected:
   virtual bool fill_from_database(); //Override.
   virtual type_vecLayoutFields get_fields_to_show() const; //override
 
-  sharedptr<const LayoutItem_Field> get_field_is_from_non_hidden_related_record() const;
-  sharedptr<const LayoutItem_Field> get_field_identifies_non_hidden_related_record() const;
-
   virtual void on_adddel_user_requested_add();
   virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
   virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& row, guint col_with_first_value); //Override.
@@ -79,6 +77,8 @@ protected:
   virtual void enable_buttons(); //override
 
 protected:
+  virtual Document_Glom::type_mapLayoutGroupSequence create_layout_get_layout(); //override.
+
   Gtk::Frame m_Frame;
   Gtk::Alignment m_Alignment;
   Gtk::Label m_Label;
